"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * A collection that contains no duplicate MetadataComponents. Components are hashed
 * by their FullName and metadata type id.
 */
class ComponentSet {
    constructor(components) {
        this.map = new Map();
        if (components) {
            for (const component of components) {
                this.map.set(this.key(component), component);
            }
        }
    }
    add(component) {
        this.map.set(this.key(component), component);
    }
    get(component) {
        return this.map.get(this.key(component));
    }
    has(component) {
        return this.map.has(this.key(component));
    }
    values() {
        return this.map.values();
    }
    *[Symbol.iterator]() {
        for (const component of this.map.values()) {
            yield component;
        }
    }
    get size() {
        return this.map.size;
    }
    key(component) {
        const typeName = typeof component.type === 'string' ? component.type.toLowerCase().trim() : component.type.id;
        return `${typeName}.${component.fullName}`;
    }
}
exports.ComponentSet = ComponentSet;
//# sourceMappingURL=componentSet.js.map